@@ -11,7 +11,7 @@
  */
 
 /*
- * $Id: hsgetopt.c,v 1.3 2002/01/27 15:37:21 jason Exp $
+ * $Id: hsgetopt.c,v 1.4 2007/03/19 18:04:54 jason Exp $
  */
 
 /*
@@ -86,9 +86,9 @@ hs_getopt(argc, argv, optstring)
 
   if (place == NULL || c == ':') {
 #ifdef _WINDOWS /* mrhmod - avoid attempt to use stderr */
-    error_exit("%s: unknown option -%c\n", argv[0], c);
+    error_exit("%s: unknown option -%c\n", argv0, c);
 #else
-    fprintf(stderr, "%s: unknown option -%c\n", argv[0], c);
+    fprintf(stderr, "%s: unknown option -%c\n", argv0, c);
 #endif
     return ('?');
   }
@@ -101,11 +101,11 @@ hs_getopt(argc, argv, optstring)
       if (hs_optind >= argc) {
 #ifdef _WINDOWS /* mrhmod - avoid attempt to use stderr */
         error_exit("%s: missing argument after -%c\n",
-          argv[0], c);
+          argv0, c);
 #else
         fprintf(stderr,
           "%s: missing argument after -%c\n",
-          argv[0], c);
+          argv0, c);
 #endif
         return ('?');
       }
