@@ -7,10 +7,15 @@
 ******************************************************************************/
 
 /*
- * $Id: shorten.c,v 1.27 2004/05/03 06:59:02 jason Exp $
+ * $Id: shorten.c,v 1.30 2007/03/19 19:48:01 jason Exp $
  */
 
-#ifdef _WINDOWS
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
+#if defined(_WINDOWS) || defined(HAVE_WINDOWS_H)
+#define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #endif
 
@@ -35,8 +40,10 @@
 #include <setjmp.h>
 #include "shorten.h"
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
+#ifdef WIN32
+#define PATHSEPCHAR '\\'
+#else
+#define PATHSEPCHAR '/'
 #endif
 
 #define V2LPCQOFFSET (1 << LPCQUANT);
@@ -385,9 +392,27 @@ void ShowSeekInfo(FILE *f,char *filename)
   fprintf(stderr,"File '%s' does not contain seek information.\n",filename);
 }
 
+#ifdef WIN32
+int truncate(char *filename,int filesize)
+{ 
+  HANDLE hFile;
+
+  if (INVALID_HANDLE_VALUE == (hFile = CreateFile(filename,GENERIC_WRITE|GENERIC_READ,0,NULL,OPEN_EXISTING,FILE_ATTRIBUTE_NORMAL,NULL)))
+    return -1;
+
+  SetFilePointer(hFile,filesize,NULL,FILE_BEGIN);
+
+  SetEndOfFile(hFile);
+  
+  CloseHandle(hFile);
+
+  return 0;
+}
+#endif
+
 void RemoveSeekInfo(char *filename)
 {
-#ifdef HAVE_TRUNCATE
+#if defined(HAVE_TRUNCATE) || defined(WIN32)
   ulong SHNFileSize,sktSize;
   TSeekTableTrailer Trailer;
   FILE *f;
@@ -408,8 +433,13 @@ void RemoveSeekInfo(char *filename)
   SHNFileSize -= sktSize;
 
   fprintf(stderr,"removing seek table from file '%s'\n",filename);
+
   if (0 != truncate(filename,SHNFileSize))
+#ifdef WIN32
+    fprintf(stderr,"error: could not truncate file: Win32 error code %d\n",GetLastError());
+#else
     fprintf(stderr,"error: could not truncate file: %s\n",strerror(errno));
+#endif
 #else
   fprintf(stderr,"error: Your system does not seem to support the truncate() function.\n");
   fprintf(stderr,"       Please report this error to <shnutils@freeshell.org>.\n");
@@ -479,6 +509,7 @@ int shorten(FILE *stdi, FILE *stdo,int argc,char **argv)
   ulong WriteCount=0;
   char SeekTableFilename[MAX_PATH];
   FILE *SeekTableFile=0;
+  char *p;
 
 #ifdef MSDOS
 #ifdef MSDOS_DO_TIMING
@@ -488,8 +519,7 @@ int shorten(FILE *stdi, FILE *stdo,int argc,char **argv)
 #endif
 #endif
 
-  argv0 = (0 == strrchr(argv[0],'/')) ? argv[0] : strrchr(argv[0],'/') + 1;
-
+  argv0 = ((p = strrchr(argv[0],PATHSEPCHAR))) ? (p + 1) : argv[0];
 
 #ifdef _WINDOWS
 /* Need to set the FILE pointers to null, so we know if they have to be closed on abort */
@@ -856,6 +886,8 @@ StartAgain:
       else {
         if (!FileHasSeekInfoAppended(filei,NULL))
           usage_exit(1,"file '%s' does not contain seek information\n",filenamei);
+
+        fclose(filei);
         RemoveSeekInfo(filenamei);
       }
       exit(0);
@@ -1849,18 +1881,19 @@ StartAgain:
       fwrite(pSeekTableBuffer,1,SeekTableSize,filei);
 
       free(pSeekTableBuffer);
-
-      if (!saw_s_op && !saw_S_op)
-        if(unlink(SeekTableFilename))
-          usage_exit(1, "could not remove seek table file '%s': %s\n",SeekTableFilename,strerror(errno));
     }
 
     /* and finally close the files */
     if (filei)
       fclose(filei);
-
     filei = 0;
+
     fclose(SeekTableFile);
+
+    if (AppendSeekInfo && !saw_s_op && !saw_S_op) {
+      if(unlink(SeekTableFilename))
+        usage_exit(1, "could not remove seek table file '%s': %s\n",SeekTableFilename,strerror(errno));
+    }
   }
 
   if (DupFileInfo)
